@@ -14,6 +14,9 @@
 #'   Additional argument, possibly passed down to the underlying plot functions.
 #'
 #' @return [ggplot2::ggplot()] object.
+#'
+#' @template section_theme
+#'
 #' @export
 #' @examples
 #' library(mlr3)
@@ -34,19 +37,34 @@ autoplot.TaskClassif = function(object, type = "target", ...) { # nolint
   switch(type,
     "target" = {
       ggplot(object, aes_string(x = target, fill = target)) +
-        geom_bar(stat = "count")
+        geom_bar(stat = "count") +
+        apply_theme(list(
+          scale_fill_viridis_d(end = 0.8),
+          scale_color_viridis_d(end = 0.8),
+          theme_mlr3()
+        ))
     },
 
     "duo" = {
       require_namespaces("GGally")
       GGally::ggduo(object,
         columnsX = target, columnsY = object$feature_names,
-        mapping = aes_string(color = target), ...)
+        mapping = aes_string(color = target), ...) +
+        apply_theme(list(
+          scale_fill_viridis_d(end = 0.8),
+          scale_color_viridis_d(end = 0.8),
+          theme_mlr3()
+        ))
     },
 
     "pairs" = {
       require_namespaces("GGally")
-      GGally::ggpairs(object, aes_string(color = target), ...)
+      GGally::ggpairs(object, aes_string(color = target), ...) +
+        apply_theme(list(
+          scale_fill_viridis_d(end = 0.8),
+          scale_color_viridis_d(end = 0.8),
+          theme_mlr3()
+        ))
     },
 
     stopf("Unknown plot type '%s'", type)
